@@ -39,44 +39,24 @@ SPEC_CORE_LAYOUT_LIST = [
 CLOUD_IMAGE_MAP = {
     "aws": {
         "arm64": {
-            "ubuntu-latest": "ami-075c8e2e1712231db",
             "ubuntu-2004": "ami-075c8e2e1712231db",
             "ubuntu-1804": "ami-09f78b2dda8a0dbd7",
-            "centos-latest": "ami-0a4c0912a6594a308",
             "centos-8": "ami-0a4c0912a6594a308",
-            "sles-latest": "ami-05122f5515f6f044a",
             "sles-15": "ami-05122f5515f6f044a",
-            "debian-latest": "ami-0fd1d3db6054b3cc9",
-            "debian-11": "ami-0fd1d3db6054b3cc9",
             "debian-10": "ami-06dac44ad759182bd",
         },
         "amd64": {
-            "ubuntu-latest": "ami-039af3bfc52681cd5",
             "ubuntu-2004": "ami-039af3bfc52681cd5",
             "ubuntu-1804": "ami-0bd586d26693ecbe9",
-            "centos-latest": "ami-057cacbfbbb471bb3",
             "centos-8": "ami-057cacbfbbb471bb3",
-            "sles-latest": "ami-0326c54d5f592764b",
             "sles-15": "ami-0326c54d5f592764b",
-            "debian-latest": "ami-04dd0542609808c50",
             "debian-11": "ami-04dd0542609808c50",
             "debian-10": "ami-0d90bed76900e679a",
-            "windows-latest": "",
-            "windows-2022": "",
-            "windows-10": "",
+            "oracle-8": "ami-00371eeb8fd8e0e16",
         },
     },
     "google": {
-        "arm64": {
-            "ubuntu-latest": "",
-            "ubuntu-2004": "",
-            "ubuntu-1804": "",
-            "sles-latest": "",
-            "sles-15": "",
-            "debian-latest": "",
-            "debian-10": "",
-            "debian-9": "",
-        },
+        "arm64": {},
         "amd64": {
             "ubuntu-latest": "ubuntu-2004-focal-v20220325",
             "ubuntu-2004": "ubuntu-2004-focal-v20220325",
